@@ -18,6 +18,11 @@
 #' the 'validation' data. The Root Mean Square Prediction Difference (RMSPD) is
 #' computed. At the end of boots, a list is returned.
 #'
+#' \strong{IMPORTANT:} If the data set is unbalanced (i.e., any genotype missing
+#' in any environment) the function will return an error. An error is also
+#' observed if any combination of genotype-environment has a different number of
+#' replications than observed in the trial.
+#'
 #' @param .data The dataset containing the columns related to Environments,
 #'   Genotypes, replication/block and response variable(s).
 #' @param env The name of the column that contains the levels of the
@@ -102,6 +107,26 @@ cv_ammif <- function(.data, env, gen, rep, resp, nboot = 200, block, design = "R
     initial <- 0
     NAXIS <- minimo
     AMMIval <- data.frame(matrix(NA, nboot, 1))
+    test <-
+      data %>%
+      n_by(ENV, GEN) %>%
+      mutate(test =
+               case_when(Y > 0 & Y != Nbloc ~ TRUE,
+                         TRUE ~ FALSE)
+      )
+    if(any(test$test == TRUE)){
+      df_test <-
+        data.frame(
+          test[which(test$test == TRUE),] %>%
+            remove_cols(rowid,REP, test) %>%
+            rename(n = Y)
+        )
+      message(paste0(capture.output(df_test), collapse = "\n"))
+      stop("Combinations of genotype and environment with different number of replication than observed in the trial (", Nbloc, ")", call. = FALSE)
+    }
+    if(!is_balanced_trial(data, ENV, GEN, Y)){
+      stop("AMMI analysis cannot be computed with unbalanced data.", call. = FALSE)
+    }
     if (verbose == TRUE) {
       pb <- progress_bar$new(
         format = "Validating :what [:bar]:percent (:elapsedfull -:eta left)",
@@ -208,6 +233,26 @@ cv_ammif <- function(.data, env, gen, rep, resp, nboot = 200, block, design = "R
     initial <- 0
     NAXIS <- minimo
     AMMIval <- data.frame(matrix(NA, nboot, 1))
+    test <-
+      data %>%
+      n_by(ENV, GEN) %>%
+      mutate(test =
+               case_when(Y > 0 & Y != Nbloc ~ TRUE,
+                         TRUE ~ FALSE)
+      )
+    if(any(test$test == TRUE)){
+      df_test <-
+        data.frame(
+          test[which(test$test == TRUE),] %>%
+            remove_cols(rowid,REP, test) %>%
+            rename(n = Y)
+        )
+      message(paste0(capture.output(df_test), collapse = "\n"))
+      stop("Combinations of genotype and environment with different number of replication than observed in the trial (", Nbloc, ")", call. = FALSE)
+    }
+    if(!is_balanced_trial(data, ENV, GEN, Y)){
+      stop("AMMI analysis cannot be computed with unbalanced data.", call. = FALSE)
+    }
     if (verbose == TRUE) {
       pb <- progress_bar$new(
         format = "Validating :what [:bar]:percent (:elapsedfull -:eta left)",
