@@ -219,7 +219,7 @@ desc_stat <- function(.data = NULL,
                        sd.pop = ~sd_pop(., na.rm = na.rm),
                        sd.amo = ~sd_amo(., na.rm = na.rm),
                        se = ~sem(., na.rm = na.rm),
-                       ci = ~ci_mean(., na.rm = na.rm),
+                       ci = ~ci_mean(., na.rm = na.rm, level = level),
                        skew = ~skew(., na.rm = na.rm),
                        kurt = ~kurt(., na.rm = na.rm),
                        cv = ~cv(., na.rm = na.rm),
