@@ -39,11 +39,13 @@
 #' @md
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
 #' @export
-#' @references Olivoto, T., A.D.C. L{\'{u}}cio, J.A.G. da silva, B.G. Sari, and M.I. Diel. 2019. Mean performance and stability in multi-environment trials II: Selection based on multiple traits. Agron. J. (in press).
+#' @references Olivoto, T., A.D.C. L{\'{u}}cio, J.A.G. da silva, B.G. Sari, and
+#'   M.I. Diel. 2019. Mean performance and stability in multi-environment trials
+#'   II: Selection based on multiple traits. Agron. J. 111:2961-2969.
+#'   doi:10.2134/agronj2019.03.0221.
 #' @examples
 #'\donttest{
 #' library(metan)
-#'
 #' # Based on stability only, for both GY and HM, higher is better
 #' mtsi_model <- waasb(data_ge,
 #'                     env = ENV,
@@ -188,7 +190,7 @@ mtsi <- function(.data,
   ideotypes.scores <- ideotypes.matrix %*% canonical.loadings
   gen_ide <- sweep(scores, 2, ideotypes.scores, "-")
   MTSI <- sort(apply(gen_ide, 1, function(x) sqrt(sum(x^2))), decreasing = FALSE)
-  contr.factor <- data.frame((gen_ide^2/apply(gen_ide, 1, function(x) sum(x^2))) * 100) %>%
+  contr.factor <- data.frame((sqrt(gen_ide^2)/apply(gen_ide, 1, function(x) sum(sqrt(x^2)))) * 100) %>%
     rownames_to_column("Gen") %>%
     as_tibble()
   means.factor <- means[, names.pos.var.factor]
@@ -223,10 +225,6 @@ mtsi <- function(.data,
     cat("-------------------------------------------------------------------------------\n")
     cat("Comunalit Mean:", mean(Communality), "\n")
     cat("-------------------------------------------------------------------------------\n")
-    cat("Multitrait stability index\n")
-    cat("-------------------------------------------------------------------------------\n")
-    print(round(MTSI, 4))
-    cat("-------------------------------------------------------------------------------\n")
     if (!is.null(ngs)) {
       cat("Selection differential for the ", index, "index\n")
       cat("-------------------------------------------------------------------------------\n")
@@ -259,7 +257,7 @@ mtsi <- function(.data,
                         canonical.loadings = data.frame(canonical.loadings) %>% rownames_to_column("VAR") %>% as_tibble(),
                         scores.gen = data.frame(scores) %>% rownames_to_column("GEN") %>% as_tibble(),
                         scores.ide = data.frame(ideotypes.scores) %>% rownames_to_column("GEN") %>% as_tibble(),
-                        MTSI = MTSI,
+                        MTSI = as_tibble(MTSI, rownames = NA) %>% rownames_to_column("Genotype") %>% rename(MTSI = value),
                         contri.fac = contr.factor,
                         sel.dif = sel.dif,
                         mean.sd = mean_sd_ind,
@@ -314,7 +312,8 @@ plot.mtsi <- function(x, SI = 15, radar = TRUE, arrange.label = FALSE, size.poin
   if (!class(x) == "mtsi") {
     stop("The object 'x' is not of class 'mtsi'")
   }
-  data <- tibble(MTSI = x$MTSI, Genotype = names(x$MTSI), sel = "Selected")
+  data <- x$MTSI %>%
+    add_cols(sel = "Selected")
   data[["sel"]][(round(nrow(data) * (SI/100), 0) + 1):nrow(data)] <- "Nonselected"
   cutpoint <- max(subset(data, sel == "Selected")$MTSI)
   p <- ggplot(data = data, aes(x = reorder(Genotype, -MTSI),
@@ -345,9 +344,6 @@ plot.mtsi <- function(x, SI = 15, radar = TRUE, arrange.label = FALSE, size.poin
 
 
 
-
-
-
 #' Print an object of class mtsi
 #'
 #' Print a \code{mtsi} object in two ways. By default, the results are shown in
