@@ -247,6 +247,7 @@ waas <- function(.data,
     for (var in 1:nvar) {
         data <- factors %>%
             mutate(Y = vars[[var]])
+        check_labels(data)
         if(has_na(data)){
             data <- remove_rows_na(data)
             has_text_in_num(data)
@@ -391,8 +392,7 @@ waas <- function(.data,
 #'      which = c(3, 5),
 #'      nrow = 2,
 #'      labels = TRUE,
-#'      size.lab.out = 4,
-#'      align = "v")
+#'      size.lab.out = 4)
 #' }
 #'
 plot.waas <- function(x, ...) {
